import { Container, GoogleReCaptcha } from '@google-recaptcha/core';
export interface GoogleReCaptchaDefaultOptions {
    host?: GoogleReCaptcha.Host;
    isEnterprise?: boolean;
    language?: string;
    scriptProps?: GoogleReCaptcha.Script;
    siteKey: string;
}
export interface Explicit {
    container?: Container;
    inherit?: boolean;
    tabIndex?: number;
    callback?: (token: string) => void;
    errorCallback?: () => void;
    expiredCallback?: () => void;
}
export interface GoogleReCaptchaV2InvisibleOptions extends GoogleReCaptchaDefaultOptions {
    type: Extract<GoogleReCaptcha.Type, 'v2-invisible'>;
    explicit?: Explicit & {
        badge?: GoogleReCaptcha.Badge;
    };
}
export interface GoogleReCaptchaV2CheckBoxOptions extends GoogleReCaptchaDefaultOptions {
    type: Extract<GoogleReCaptcha.Type, 'v2-checkbox'>;
    explicit?: Explicit & {
        container: Container;
        action?: GoogleReCaptcha.Action['action'];
        theme?: GoogleReCaptcha.Theme;
        size?: GoogleReCaptcha.Size['v2-checkbox'];
    };
}
export interface GoogleReCaptchaV3Options extends GoogleReCaptchaDefaultOptions {
    type: Extract<GoogleReCaptcha.Type, 'v3'>;
    explicit?: Explicit & {
        badge?: GoogleReCaptcha.Badge;
    };
}
export type GoogleReCaptchaOptions = GoogleReCaptchaV2CheckBoxOptions | GoogleReCaptchaV2InvisibleOptions | GoogleReCaptchaV3Options;
export interface GoogleReCaptchaState {
    googleReCaptcha?: GoogleReCaptcha.Instance;
    isLoading: boolean;
    language?: GoogleReCaptcha.Language;
    siteKey: string;
    executeV2Invisible: (optWidgetId?: GoogleReCaptcha.OptWidgetId) => Promise<void>;
    executeV3: (action: GoogleReCaptcha.Action['action']) => Promise<string>;
    getResponse?: (optWidgetId?: GoogleReCaptcha.OptWidgetId) => string;
    render?: (container: Container, parameters?: GoogleReCaptcha.Parameters, inherit?: boolean) => number;
    reset?: (optWidgetId?: GoogleReCaptcha.OptWidgetId) => void;
}
export declare const useGoogleReCaptchaProvider: (options: GoogleReCaptchaOptions) => {
    readonly instance: GoogleReCaptcha.Instance | undefined;
    readonly siteKey: string;
    readonly isLoading: boolean;
    readonly language: GoogleReCaptcha.Language;
    readonly executeV3: (action: GoogleReCaptcha.Action["action"]) => Promise<string>;
    readonly executeV2Invisible: (optWidgetId?: GoogleReCaptcha.OptWidgetId) => Promise<void>;
    readonly reset: ((opt_widget_id?: GoogleReCaptcha.OptWidgetId) => void) | undefined;
    readonly getResponse: ((opt_widget_id?: GoogleReCaptcha.OptWidgetId) => string) | undefined;
    readonly render: ((container: Container, parameters?: GoogleReCaptcha.Parameters, inherit?: boolean) => number) | undefined;
};
